aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMike Gabriel <mike.gabriel@das-netzwerkteam.de>2018-05-06 13:10:21 +0200
committerMike Gabriel <mike.gabriel@das-netzwerkteam.de>2018-05-06 13:10:21 +0200
commitf04ac9c8a6e28d1af02c7e590a957bdfcacb51fe (patch)
treeff5444786a9711b3b77bf029eded9395a390637c
parent6ec601eec5de284dc561fd8fc101a28a815453cf (diff)
downloadlibpam-freerdp2-f04ac9c8a6e28d1af02c7e590a957bdfcacb51fe.tar.gz
libpam-freerdp2-f04ac9c8a6e28d1af02c7e590a957bdfcacb51fe.tar.bz2
libpam-freerdp2-f04ac9c8a6e28d1af02c7e590a957bdfcacb51fe.zip
src/pam-freerdp.c: Update some comments.
-rw-r--r--src/pam-freerdp2.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/src/pam-freerdp2.c b/src/pam-freerdp2.c
index 45ba346..00e0e0c 100644
--- a/src/pam-freerdp2.c
+++ b/src/pam-freerdp2.c
@@ -57,10 +57,10 @@ static char *
get_item (pam_handle_t * pamh, int type)
{
/* Check to see if we just have the value. If we do, great
- let's dup it some we're consitently allocating memory */
+ let's dup it some we're consistently allocating memory */
if ((type == PAM_USER) || (type == PAM_AUTHTOK)) {
- /* If it's not a domain we can use the PAM functions because the PAM
- functions don't support the domain */
+ /* If it's not an RDP parameter type we can use the PAM functions because the PAM
+ functions don't support RDP parameters */
char * value = NULL;
if (pam_get_item(pamh, type, (const void **)&value) == PAM_SUCCESS && value != NULL) {
return value;
@@ -71,8 +71,7 @@ get_item (pam_handle_t * pamh, int type)
return global_password;
}
} else {
- /* Here we only have domains, so we can see if the global domain is
- useful for us, if we have it */
+ /* Here we deal with all RDP specific parameters */
if ((type == PAM_TYPE_RDP_USER) && (global_rdp_user != NULL)) {
return global_rdp_user;
}